Changelog
=========

0.7
---

* Released on 17th Match 2021.
* Fixed minor syntax issue in user data schema.

0.6
---

* Released on 5th Match 2021.
* Improved examples.
* Fixed license information.

0.5
---

* Released on 8th Decemeber 2020.
* Fixed validation of translation memory entries with newlines.

0.4
---

* Released on 5th August 2020.
* Added schema for user downloadable data.

0.3
---

* Released on 10th March 2020.
* Switch to more standard naming of schema files (.schema.json).

0.2
---

* Released on 10th March 2020.
* Fixed language code validation.

0.1
---

* Released on 10th March 2020.
* Initial release.
